@@ -4,7 +4,6 @@ from logging import getLogger, Logger, StreamHandler, Formatter
 from pathlib import Path
 from importlib import import_module
 import logging
-import os
 import pdb
 import sys
 
@@ -13,11 +12,37 @@ LOG = getLogger(__name__)
 
 LOG_LEVEL = logging.INFO
 
-LOGGER_NAME_CANDIDATES = 'logger', '_LOG', 'LOG'
+_TEMPLATE = '''#!/usr/bin/env python3
+from logging import getLogger
+
+
+LOG = getLogger(__name__)
+
+
+def set_logger(parent_name):
+    global LOG
+    LOG = getLogger(f'{parent_name}.{__name__}')
+
+
+def add_arguments(parser):
+    group = parser.add_argument_group(__name__)
+    ...
+
+
+def main(args):
+    ...
+
+
+# code below is an option.
+# if you want to run it as an normal Python script
+# (`python THIS_SCRIPT.py`), uncomment it.
+# if __name__ == '__main__':
+#     import wrapp
+#     wrapp.main(add_arguments, main, set_logger)'''
 
 
 def _import_module():
-    sys.path.insert(0, os.getcwd())
+    sys.path.insert(0, Path().cwd())
     assert len(sys.argv) > 1, sys.argv
     args = sys.argv[1:]
     argv0_path = Path(args[0])
@@ -32,31 +57,15 @@ def _import_module():
     return module
 
 
-def _set_loggers(module):
-    _set_logger(LOG, LOG_LEVEL)
-    module_logger = _get_module_logger(module)
-    if module_logger is not None:
-        _set_logger(module_logger, LOG_LEVEL)
-
-
 def _parse_module_arguments(module):
     parser = ArgumentParser(
             prog=sys.argv[1],
             formatter_class=ArgumentDefaultsHelpFormatter)
     module.add_arguments(parser)
     args = parser.parse_args(sys.argv[2:])
-    _print_args(args)
     return args
 
 
-def _get_module_logger(module):
-    for c in LOGGER_NAME_CANDIDATES:
-        if hasattr(module, c):
-            return getattr(module, c)
-    LOG.warning(
-            f'{module.__name__} does not have any of {LOGGER_NAME_CANDIDATES}')
-
-
 def _set_logger(logger, level):
     if not isinstance(logger, Logger):
         LOG.warning((
@@ -70,7 +79,6 @@ def _set_logger(logger, level):
     ))
     logger.setLevel(level)
     logger.addHandler(__handler)
-    logger.propagate = False
 
 
 def _print_args(args):
@@ -83,40 +91,37 @@ def _parse_args(add_arguments_func):
             formatter_class=ArgumentDefaultsHelpFormatter)
     add_arguments_func(parser)
     args = parser.parse_args()
-    _print_args(args)
     return args
 
 
 def app():
+    '''
+    comes here when wrapp YOUR_SCRIPT ... is run.
+    '''
     module = _import_module()
-    _set_loggers(module)
+    _set_logger(LOG, LOG_LEVEL)
+    if hasattr(module, 'set_logger'):
+        module.set_logger(LOG.name)
     args = _parse_module_arguments(module)
+    _print_args(args)
     module.main(args)
 
 
-_TEMPLATE = '''#!/usr/bin/env python3
-from logging import getLogger
-
-
-logger = getLogger(__name__)
-
-
-def add_arguments(parser):
-    group = parser.add_argument_group(__name__)
-    ...
-
-
-def main(args):
-    ...'''
-
-
 def new():
-    print(_TEMPLATE)
+    '''
+    comes here when wrapp.new is run.
+    '''
+    print(_TEMPLATE, end='')
 
 
-def main(add_arguments_func, main_func, logger):
-    _set_logger(logger, LOG_LEVEL)
+def main(add_arguments_func, main_func, set_logger_func):
+    '''
+    use this function when you want to use usual if __name__ == '__main__': block.
+    '''
+    set_logger_func(LOG.name)
+    _set_logger(LOG, LOG_LEVEL)
     args = _parse_args(add_arguments_func)
+    _print_args(args)
     main_func(args)
 
 
